

.. image:: https://travis-ci.org/sonofeft/ParaSol.svg?branch=master
    :target: https://travis-ci.org/sonofeft/ParaSol

.. image:: https://img.shields.io/pypi/v/ParaSol.svg
    :target: https://pypi.python.org/pypi/parasol
        
.. image:: https://img.shields.io/pypi/pyversions/ParaSol.svg
    :target: https://wiki.python.org/moin/Python2orPython3

.. image:: https://img.shields.io/pypi/l/ParaSol.svg
    :target: https://pypi.python.org/pypi/parasol


Parasol is a Framework for Parametric Model Investigation.
==========================================================


See the Code at: `<https://github.com/sonofeft/ParaSol>`_

See the Docs at: `<http://parasol.readthedocs.org/en/latest/>`_

See PyPI page at:`<https://pypi.python.org/pypi/parasol>`_

See Original 2009 code at: `<http://pyparasol.sourceforge.net/overview.html>`_

Parasol enables easy optimization, sensitivity study, and visualization. 
The math model can be as big or as small as desired. 

Output is generated in plain text, HTML, and (On Windows) native Microsoft Suite files (Excel, Word and PowerPoint).

A problem is defined by input and output parameters. 
Results are presented in a manner that conveys insight into system trends and characteristics. 
The process of performing an analysis results in an ample assortment of graphs, charts, and images that display system sensitivities, variations, and characteristics. 
Barriers to creating these displays have been reduced to single commands in order to facilitate their use.

Parasol has been designed to run best under Microsoft Windows, but also runs under Linux.

TODO... Add support for Libreoffice and OpenOffice on both Linux and Windows
